@@ -7,61 +7,62 @@ Coro::State - first class continuations
  use Coro::State;
 
  $new = new Coro::State sub {
-    print "in coroutine (called with @_), switching back\n";
+    print "in coro (called with @_), switching back\n";
     $new->transfer ($main);
-    print "in coroutine again, switching back\n";
+    print "in coro again, switching back\n";
     $new->transfer ($main);
  }, 5;
 
  $main = new Coro::State;
 
- print "in main, switching to coroutine\n";
+ print "in main, switching to coro\n";
  $main->transfer ($new);
- print "back in main, switch to coroutine again\n";
+ print "back in main, switch to coro again\n";
  $main->transfer ($new);
  print "back in main\n";
 
 =head1 DESCRIPTION
 
-This module implements coroutines. Coroutines, similar to continuations,
+This module implements coro. Coros, similar to threads and continuations,
 allow you to run more than one "thread of execution" in parallel. Unlike
-threads, there is no parallelism and only voluntary switching is used so
-locking problems are greatly reduced.
+so-called "kernel" threads, there is no parallelism and only voluntary
+switching is used so locking problems are greatly reduced. The latter is
+called "cooperative" threading as opposed to "preemptive" threading.
 
 This can be used to implement non-local jumps, exception handling,
-(non-clonable) continuations and more.
+continuation objects and more.
 
 This module provides only low-level functionality. See L<Coro> and related
-modules for a higher level process abstraction including scheduling.
+modules for a higher level threads abstraction including a scheduler.
 
 =head2 MODEL
 
-Coro::State implements two different coroutine models: Perl and C. The
-C coroutines (called cctx's) are basically simplified perl interpreters
-running/interpreting the Perl coroutines. A single interpreter can run any
-number of Perl coroutines, so usually there are very few C coroutines.
+Coro::State implements two different thread models: Perl and C. The C
+threads (called cctx's) are basically simplified perl interpreters
+running/interpreting the Perl threads. A single interpreter can run any
+number of Perl threads, so usually there are very few C threads.
 
-When Perl code calls a C function (e.g. in an extension module) and that
-C function then calls back into Perl or does a coroutine switch the C
-coroutine can no longer execute other Perl coroutines, so it stays tied to
-the specific coroutine until it returns to the original Perl caller, after
-which it is again available to run other Perl coroutines.
+When Perl code calls a C function (e.g. in an extension module) and that C
+function then calls back into Perl or transfers control to another thread,
+the C thread can no longer execute other Perl threads, so it stays tied to
+the specific thread until it returns to the original Perl caller, after
+which it is again available to run other Perl threads.
 
-The main program always has its own "C coroutine" (which really is
+The main program always has its own "C thread" (which really is
 *the* Perl interpreter running the whole program), so there will always
-be at least one additional C coroutine. You can use the debugger (see
-L<Coro::Debug>) to find out which coroutines are tied to their cctx and
+be at least one additional C thread. You can use the debugger (see
+L<Coro::Debug>) to find out which threads are tied to their cctx and
 which aren't.
 
 =head2 MEMORY CONSUMPTION
 
-A newly created coroutine that has not been used only allocates a
+A newly created Coro::State that has not been used only allocates a
 relatively small (a hundred bytes) structure. Only on the first
 C<transfer> will perl allocate stacks (a few kb, 64 bit architetcures
-use twice as much, i.e. a few kb :) and optionally a C stack/coroutine
-(cctx) for coroutines that recurse through C functions. All this is very
+use twice as much, i.e. a few kb :) and optionally a C stack/thread
+(cctx) for threads that recurse through C functions. All this is very
 system-dependent. On my x86-pc-linux-gnu system this amounts to about 2k
-per (non-trivial but simple) coroutine.
+per (non-trivial but simple) Coro::State.
 
 You can view the actual memory consumption using Coro::Debug. Keep in mind
 that a for loop or other block constructs can easily consume 100-200 bytes
@@ -92,7 +93,7 @@ sub warnhook { &$WARNHOOK }
 use XSLoader;
 
 BEGIN {
-   our $VERSION = 5.12;
+   our $VERSION = 5.13;
 
    # must be done here because the xs part expects it to exist
    # it might exist already because Coro::Specific created it.
@@ -121,8 +122,8 @@ use base Exporter::;
 =item $Coro::State::DIEHOOK
 
 This works similarly to C<$SIG{__DIE__}> and is used as the default die
-hook for newly created coroutines. This is useful if you want some generic
-logging function that works for all coroutines that don't set their own
+hook for newly created Coro::States. This is useful if you want some generic
+logging function that works for all threads that don't set their own
 hook.
 
 When Coro::State is first loaded it will install these handlers for the
@@ -137,8 +138,8 @@ must not return from your die hook - terminate instead.
 Note 1: You I<must> store a valid code reference in these variables,
 C<undef> will I<not> do.
 
-Note 2: The value of this variable will be shared among all coroutines, so
-changing its value will change it in all coroutines that don't have their
+Note 2: The value of this variable will be shared among all threads, so
+changing its value will change it in all threads that don't have their
 own die handler.
 
 =item $Coro::State::WARNHOOK
@@ -153,15 +154,15 @@ Similar to above die hook, but augments C<$SIG{__WARN__}>.
 
 =item $coro = new Coro::State [$coderef[, @args...]]
 
-Create a new coroutine and return it. The first C<transfer> call to this
-coroutine will start execution at the given coderef, with the given
-arguments.
+Create a new Coro::State thread object and return it. The first
+C<transfer> call to this thread will start execution at the given
+coderef, with the given arguments.
 
 Note that the arguments will not be copied. Instead, as with normal
-function calls, the coroutine receives passed arguments by reference, so
+function calls, the thread receives passed arguments by reference, so
 make sure you don't change them in unexpected ways.
 
-Returning from such a coroutine is I<NOT> supported. Neither is calling
+Returning from such a thread is I<NOT> supported. Neither is calling
 C<exit> or throwing an uncaught exception. The following paragraphs
 describe what happens in current versions of Coro.
 
@@ -171,26 +172,26 @@ of the main program ended.
 If it throws an exception the program will terminate unless the exception
 is caught, exactly like in the main program.
 
-Calling C<exit> in a coroutine does the same as calling it in the main
+Calling C<exit> in a thread does the same as calling it in the main
 program, but due to libc bugs on many BSDs, this doesn't work reliable
 everywhere.
 
 If the coderef is omitted this function will create a new "empty"
-coroutine, i.e. a coroutine that cannot be transfered to but can be used
-to save the current coroutine state in (note that this is dangerous, as no
-reference is taken to ensure that the "current coroutine state" survives,
+thread, i.e. a thread that cannot be transfered to but can be used
+to save the current thread state in (note that this is dangerous, as no
+reference is taken to ensure that the "current thread state" survives,
 the caller is responsible to ensure that the cloned state does not go
 away).
 
 The returned object is an empty hash which can be used for any purpose
 whatsoever, for example when subclassing Coro::State.
 
-Certain variables are "localised" to each coroutine, that is, certain
-"global" variables are actually per coroutine. Not everything that would
+Certain variables are "localised" to each thread, that is, certain
+"global" variables are actually per thread. Not everything that would
 sensibly be localised currently is, and not everything that is localised
 makes sense for every application, and the future might bring changes.
 
-The following global variables can have different values per coroutine,
+The following global variables can have different values per thread,
 and have the stated initial values:
 
    Variable       Initial Value
@@ -213,14 +214,43 @@ variables. Yes, this is by design ;) You can always create your own
 process abstraction model that saves these variables.
 
 The easiest way to do this is to create your own scheduling primitive like
-in the code below, and use it in your coroutines:
+in the code below, and use it in your threads:
 
   sub my_cede {
      local ($;, ...);
      Coro::cede;
   }
 
-=cut
+Another way is to use dynamic winders, see C<Coro::on_enter> and
+C<Coro::on_leave> for this.
+
+=item $prev->transfer ($next)
+
+Save the state of the current subroutine in C<$prev> and switch to the
+thread saved in C<$next>.
+
+The "state" of a subroutine includes the scope, i.e. lexical variables and
+the current execution state (subroutine, stack).
+
+=item $state->is_new
+
+Returns true iff this Coro::State object is "new", i.e. has never been run
+yet. Those states basically consist of only the code reference to call and
+the arguments, but consumes very little other resources. New states will
+automatically get assigned a perl interpreter when they are transfered to.
+
+=item $state->is_destroyed
+
+Returns true iff the Coro::State object has been destroyed (by
+C<cancel>), i.e. it's resources freed because they were C<cancel>'d (or
+C<terminate>'d).
+
+=item $state->cancel
+
+Forcefully destructs the given Coro::State. While you can keep the
+reference, and some memory is still allocated, the Coro::State object is
+effecticely dead, destructors have been freed, it cannot be transfered to
+anymore.
 
 =item $state->throw ([$scalar])
 
@@ -244,24 +274,16 @@ Like C<call>, but eval's the string. Dangerous.
 
 Swap the current C<$_> (swap_defsv) or C<@_> (swap_defav) with the
 equivalent in the saved state of C<$state>. This can be used to give the
-coroutine a defined content for C<@_> and C<$_> before transfer'ing to it.
+coro a defined content for C<@_> and C<$_> before transfer'ing to it.
 
 =item $state->trace ($flags)
 
 Internal function to control tracing. I just mention this so you can stay
 away from abusing it.
 
-=item $prev->transfer ($next)
-
-Save the state of the current subroutine in C<$prev> and switch to the
-coroutine saved in C<$next>.
-
-The "state" of a subroutine includes the scope, i.e. lexical variables and
-the current execution state (subroutine, stack).
-
 =item $bytes = $state->rss
 
-Returns the memory allocated by the coroutine (which includes static
+Returns the memory allocated by the coro (which includes static
 structures, various perl stacks but NOT local variables, arguments or any
 C context data). This is a rough indication of how much memory it might
 use.
@@ -274,20 +296,20 @@ use a cctxts when needed.
 
 =item Coro::State::force_cctx
 
-Forces the allocation of a C context for the currently running coroutine
+Forces the allocation of a C context for the currently running coro
 (if not already done). Apart from benchmarking there is little point
 in doing so, however.
 
 =item $ncctx = Coro::State::cctx_count
 
-Returns the number of C-level coroutines allocated. If this number is
+Returns the number of C-level coro allocated. If this number is
 very high (more than a dozen) it might help to identify points of C-level
-recursion in your code and moving this into a separate coroutine.
+recursion in your code and moving this into a separate coro.
 
 =item $nidle = Coro::State::cctx_idle
 
 Returns the number of allocated but idle (free for reuse) C level
-coroutines. Currently, Coro will limit the number of idle/unused cctxs to
+coro. Currently, Coro will limit the number of idle/unused cctxs to
 8.
 
 =item $old = Coro::State::cctx_stacksize [$new_stacksize]
@@ -298,7 +320,7 @@ be changed, but Coro will try to replace smaller stacks as soon as
 possible. Any Coro::State that starts to use a stack after this call is
 guaranteed this minimum stack size.
 
-Please note that Coroutines will only need to use a C-level stack if the
+Please note that coros will only need to use a C-level stack if the
 interpreter recurses or calls a function in a module that calls back into
 the interpreter, so use of this feature is usually never needed.
 
@@ -325,7 +347,7 @@ Since its only known purpose is for intellectual self-gratification, and
 because it is a difficult piece of code, it is not enabled by default, and
 not supported.
 
-Here are a few little-known facts: First, coroutines *are* full/true/real
+Here are a few little-known facts: First, coros *are* full/true/real
 continuations. Secondly Coro::State objects (without clone) *are* first
 class continuations. Thirdly, nobody has ever found a use for the full
 power of call/cc that isn't better (faster, easier, more efficiently)
@@ -378,12 +400,12 @@ references, and its scoping rules) then in, say, scheme.
 
 Now, the known limitations of C<clone>:
 
-It probably only works on perl 5.10; it cannot clone a coroutine inside
+It probably only works on perl 5.10; it cannot clone a coro inside
 the substition operator (but windows perl can't fork from there either)
 and some other contexts, and C<abort ()> is the preferred mechanism to
 signal errors. It cannot clone a state that has a c context attached
 (implementing clone on the C level is too hard for me to even try),
-which rules out calling call/cc from the main coroutine. It cannot
+which rules out calling call/cc from the main coro. It cannot
 clone a context that hasn't even been started yet. It doesn't work with
 C<-DDEBUGGING> (but what does). It probably also leaks, and sometimes
 triggers a few assertions inside Coro. Most of these limitations *are*
@@ -406,8 +428,8 @@ sub debug_desc {
 {
    package Coro;
 
-   our $main;    # main coroutine
-   our $current; # current coroutine
+   our $main;    # main coro
+   our $current; # current coro
 
    $main = Coro::State::new Coro::;
 
